@@ -7,6 +7,7 @@ import sys
 from matplotlib.figure import Figure
 import matplotlib.colors as colors
 import matplotlib.pyplot as plt
+from mpl_toolkits.mplot3d import Axes3D
 import pathlib
 import warnings
 from decimal import Decimal
@@ -23,10 +24,9 @@ matplotlib.use('TkAgg')
 
 class Experimento:
 
-    def __init__(self, nombre_archivo, dimension_caja=[100, 100], cantidad_filas=10, cantidad_columnas=10,
-                 procesar_tiempo_archivo_irregular=False, puntos_importantes=None, objeto_a_promediar=1,
-                 tamanio_intervalo_para_promedio=100, genera_matriz_recurrencia=False, arreglo_regiones_preferidas=None,
-                 genera_regiones_preferidas=True, distancia_max_para_volumenes=24, division_de_dist_max=2):
+    def __init__(self, nombre_archivo, dimension_caja=[100, 100], cantidad_filas=10,
+                 cantidad_columnas=10, procesar_tiempo_archivo_irregular=False,
+                 puntos_importantes=None, genera_matriz_recurrencia=False):
         self.nombre_archivo = nombre_archivo
         print("NOMBRE_ARCHIVO:", self.nombre_archivo, "\n TIPO_ARCHIVO:", type(self.nombre_archivo))
         self.dimension_caja = dimension_caja
@@ -118,11 +118,7 @@ class Experimento:
                                          self.objeto_relevante_3,
                                          self.objeto_relevante_4]
 
-        self.regiones_preferidas = arreglo_regiones_preferidas
-        total_regiones = list(range(0, cantidad_columnas*cantidad_filas))
-        self.regiones_no_preferidas = rp.obtener_complemento_de_sublista(lista=total_regiones,
-                                                                         sublista=self.regiones_preferidas)
-
+        self.cantidad_posiciones_volumenes = None
         self.radios_volumenes = None
 
         self.distancia_a_objeto_promediado = None
@@ -205,8 +201,6 @@ class Experimento:
         self.cantidad_posiciones_volumen_2 = None
         self.cantidad_posiciones_volumen_3 = None
         self.cantidad_posiciones_volumen_4 = None
-        self.distancia_max_para_volumenes = distancia_max_para_volumenes
-        self.division_de_dist_max = division_de_dist_max
         self.radios_volumenes = None
 
         print("Construcción de series de tiempo y de posición.")
@@ -218,8 +212,7 @@ class Experimento:
             raise Exception('Hay un dato en el eje Y que es mayor que la dimensión de la caja. Valor: ',
                             self.posiciones_y.max())
 
-        self.realiza_procesamiento_MOTUS(objeto_a_promediar, tamanio_intervalo_para_promedio,
-                                         genera_matriz_recurrencia, genera_regiones_preferidas)
+        self.realiza_procesamiento_MOTUS()
 
         """
         self.reduce_elementos_sesion_con_modulo(tamanio=tamanio_de_subsucesiones,
@@ -228,16 +221,13 @@ class Experimento:
                                                 subsucesiones_aleatorias=subsucesiones_aleatorias)
         """
 
-    def realiza_procesamiento_MOTUS(self, objeto, intervalo, genera_matriz_recurrencia, genera_regiones_preferidas):
+    def realiza_procesamiento_MOTUS(self):
         self.calcula_distancias()
         self.calcula_distancia_promediada_con_objeto(objeto, intervalo)
         self.calcula_velocidades()
         self.calcula_velocidades_promediadas()
         self.calcula_regiones_cuadriculadas()
-        if genera_matriz_recurrencia is True:
-            self.calcula_matrices_de_recurrencia()
-        if genera_regiones_preferidas is True:
-            self.calcula_matrices_regiones_preferidas()
+        self.calcula_matrices_regiones_preferidas()
 
     def verifica_intervalo_tiempo(self):
         arreglo_tiempo = self.tiempo
@@ -882,7 +872,6 @@ class Experimento:
         objeto_3_seleccionado = objetos_seleccionados[2]
         objeto_4_seleccionado = objetos_seleccionados[3]
 
-
         fig = Figure(figsize=(6, 6))
         plt = fig.add_subplot(111)
         plt.grid(True)
@@ -906,7 +895,6 @@ class Experimento:
             if objeto_4_seleccionado is True:
                 plt.plot(self.objeto_relevante_4[0], self.objeto_relevante_4[1], 'o', color='orange')
 
-
         elif nombre_grafica == 'ruta_vectoriales_consecuencia':
 
             brinco_temporal, tamanio_vectores, consecuencia_elegida = \
@@ -1016,6 +1004,12 @@ class Experimento:
         elif nombre_grafica == 'dist_prom':
             print("Entro a distancia promediada a objeto")
 
+            objetos_a_utilizar, objeto_a_promediar, tamanio_intervalo_para_promedio = \
+                config_grafica.regresa_config_grafica_distancias()
+
+            self.calcula_distancia_promediada_con_objeto(objeto_a_promediar,
+                                                         tamanio_intervalo_para_promedio)
+
             if lim_inf_y is None and lim_sup_y is None:
                 plt.set_ylim(min(self.dist_objeto_1), max(self.dist_objeto_1) + 5)
 
@@ -1167,11 +1161,19 @@ class Experimento:
 
             tipo_regresion_lineal, brinco_temporal, longitud_serie_tiempo = config_grafica.regresa_config_grafica_regresion_lineal()
 
-            if tipo_regresion_lineal is "Velocidad":
+            print("Tipo regresion lineal: ", tipo_regresion_lineal)
+            print("Brinco temporal: ", brinco_temporal)
+            print("Longitud Serie Tiempo: ", longitud_serie_tiempo)
+
+            if tipo_regresion_lineal == "Velocidad":
+                print("Caso Velocidad")
                 arreglo_series_tiempo = np.array(self.serie_velocidad)
-            elif tipo_regresion_lineal is "Aceleración":
+            elif tipo_regresion_lineal == "Aceleración":
+                print("Caso aceleración")
                 arreglo_series_tiempo = np.array(self.serie_aceleracion)
 
+            print("Arreglo series tiempo: ", arreglo_series_tiempo)
+
             indices_tiempo, series_tiempo = arl.generar_series_tiempo(lista_a_procesar=arreglo_series_tiempo,
                                                                       brinco_temporal=brinco_temporal,
                                                                       longitud_ventana_tiempo=longitud_serie_tiempo)
@@ -1186,14 +1188,22 @@ class Experimento:
         elif nombre_grafica == 'cilindros_objetos_importantes':
             print("Entro a volumenes_objetos_importantes")
 
-            tamanio_volumenes, div_volumenes, tipo_grafica_volumen, rot_grafica_3d = config_grafica.regresa_config_grafica_figuras()
+            tamanio_volumenes, div_volumenes, tipo_grafica_volumen, rot_grafica_3d = \
+                config_grafica.regresa_config_grafica_figuras()
 
-            cilindros.calcula_alturas_volumenes_circulares_objetos_relevantes(posiciones_x=self.posiciones_x,
-                                                                              posiciones_y=self.posiciones_y,
-                                                                              lista_objetos_relevantes=self.lista_objetos_relevantes,
-                                                                              tamanio=tamanio_volumenes,
-                                                                              divisiones=div_volumenes,
-                                                                              tipo=tipo_grafica_volumen)
+            print("Tamaño_volumenes:", tamanio_volumenes)
+            print("Div_volumenes:",div_volumenes)
+            print("tipo_grafica_volumen:",tipo_grafica_volumen)
+            print("rot_grafica_3d", rot_grafica_3d)
+
+            self.cantidad_posiciones_volumenes, self.radios_volumenes = \
+                cilindros.calcula_alturas_volumenes_circulares_objetos_relevantes(posiciones_x=self.posiciones_x,
+                                                                                  posiciones_y=self.posiciones_y,
+                                                                                  lista_objetos_relevantes=
+                                                                                  self.lista_objetos_relevantes,
+                                                                                  tamanio=tamanio_volumenes,
+                                                                                  divisiones=div_volumenes,
+                                                                                  tipo=tipo_grafica_volumen)
 
             if getattr(sys, 'frozen', False):
                 os.environ['BASEMAPDATA'] = os.path.join(os.path.dirname(sys.executable), 'mplot3d')
@@ -1201,30 +1211,30 @@ class Experimento:
             ax = fig.add_subplot(111, projection='3d')
             ax.view_init(azim=rot_grafica_3d % 360, elev=0)
 
-            for i in range(0, len(self.cantidad_posiciones_volumen_1)):
+            for i in range(0, len(self.cantidad_posiciones_volumenes[0])):
                 if objeto_1_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_1[0],
                                        self.objeto_relevante_1[1],
                                        self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumen_1[i],
+                                       self.cantidad_posiciones_volumenes[0][i],
                                        ax)
                 if objeto_2_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_2[0],
                                        self.objeto_relevante_2[1],
                                        self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumen_2[i],
+                                       self.cantidad_posiciones_volumenes[1][i],
                                        ax)
                 if objeto_3_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_3[0],
                                        self.objeto_relevante_3[1],
                                        self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumen_3[i],
+                                       self.cantidad_posiciones_volumenes[2][i],
                                        ax)
                 if objeto_4_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_4[0],
                                        self.objeto_relevante_4[1],
                                        self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumen_4[i],
+                                       self.cantidad_posiciones_volumenes[3][i],
                                        ax)
             ax.set_xlim(0, 100)
             ax.set_ylim(0, 100)
@@ -1421,7 +1431,20 @@ class Experimento:
 
             print("Entro a regionCuadricula3d, solo regiones preferidas")
 
-            rot_grafica_3d = 220
+            regiones_preferidas = config_grafica.regiones_preferidas_3d
+            print("Regiones preferidas: ", regiones_preferidas)
+            total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
+            regiones_no_preferidas = rp.obtener_complemento_de_sublista(lista=total_regiones,
+                                                                        sublista=regiones_preferidas)
+            print("Regiones no preferidas: ", regiones_no_preferidas)
+
+            self.matriz_cuadriculada_solo_regiones_preferidas = \
+                rp.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
+                                                   regiones_preferidas)
+            self.matriz_cuadriculada_solo_regiones_preferidas = \
+                np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
+
+            rot_grafica_3d = config_grafica.rot_grafica_3d
 
             objeto_1_x = self.objeto_relevante_1[0]
             objeto_1_y = self.objeto_relevante_1[1]
@@ -1505,7 +1528,20 @@ class Experimento:
 
             print("Entro a regionCuadricula3d, solo regiones no preferidas")
 
-            rot_grafica_3d = 220
+            regiones_preferidas = config_grafica.regiones_preferidas_3d
+            print("Regiones preferidas: ", regiones_preferidas)
+            total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
+            regiones_no_preferidas = rp.obtener_complemento_de_sublista(lista=total_regiones,
+                                                                        sublista=regiones_preferidas)
+            print("Regiones no preferidas: ", regiones_no_preferidas)
+
+            self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+                rp.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
+                                                   regiones_no_preferidas)
+            self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+                np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
+
+            rot_grafica_3d = config_grafica.rot_grafica_3d
 
             objeto_1_x = self.objeto_relevante_1[0]
             objeto_1_y = self.objeto_relevante_1[1]
